//
// File: GUI.cc
// Created by: Eric Laly <elaly@free.fr>
// Created on: Fri Sep  9 13:43:34 2005
//

#include "GUI.h"
#include <wx/colordlg.h>
#include <wx/progdlg.h>

GUI::GUI(wxWindow* parent, int id, const wxString& title,
				const wxPoint& pos, const wxSize& size,long style):
			FramePrincipal(parent,id, title, pos, size, style)

{
		
	// on connecte les événements
	Connect(button_encadrer->GetId( ), wxEVT_COMMAND_BUTTON_CLICKED, 
											(wxObjectEventFunction) &GUI::on_click_button_encadrer);
	
}

void GUI::on_click_button_encadrer(wxCommandEvent& event)
{
    Hide();
    CreeListeImage();
    text_ctrl_log->Clear();
    text_ctrl_log->AppendText(EncadreFichiers());
    Show();
}

void GUI::CreeListeImage()
{
    // on ouvre le répertoire source et on récupère les fichiers dont les extensions correspondent à des images
   liste_images.clear();
	wxDir dir(panel_choix_images->GetRepertoireSource());
	if (!dir.IsOpened())
	{
			text_ctrl_log->AppendText(wxT("erreur lors de l'ouverture du répertoire source\n"));
	} else{
        RecupereFichiers(wxT("*.jpg"),dir);
        RecupereFichiers(wxT("*.jpeg"),dir);
        #ifndef WIN32 // Windows
            RecupereFichiers(wxT("*.JPG"),dir);
            RecupereFichiers(wxT("*.JPEG"),dir);
        #endif
	}	
}    

void GUI::RecupereFichiers(wxString extension,wxDir &dir)
{
    //on récupère les fichiers avec l'extension indiquée dans le répertoire source et on les met dans la liste
    wxString nomfichier(wxT(""));
    int flags=wxDIR_FILES;
    wxString filespec(extension);
    bool cont=dir.GetFirst(&nomfichier,filespec,flags);
    while (cont)
    {
        liste_images.push_back(nomfichier);
        cont=dir.GetNext(&nomfichier);
    }
}    

wxString GUI::EncadreFichiers()
{
    int nombre_encadrement=panel_parametres_sortie->GetNombreEncadrement();
    int nombre_images=liste_images.size();
    wxString log(wxT(""));

    wxProgressDialog dialog (wxT("Encadrement en cours..."),wxT(""),nombre_encadrement*nombre_images+1,
        this, wxPD_CAN_ABORT|wxPD_APP_MODAL|wxPD_ELAPSED_TIME);

    // on fixe les paramètres d'encadrement
    if (!encadreur.SetPourcentagesCadres(panel_cadres->GetPourcentages())) 
        wxLogFatalError(wxT("erreur affectation pourcentage cadres"));
    encadreur.SetCouleursCadres(panel_cadres->GetCouleurs());
    encadreur.SetCouleursAutoCadres(panel_cadres->GetCouleursAuto());
    
    if (!encadreur.SetPourcentageFonteSignature(panel_signature->GetPourcentage())) 
        wxLogFatalError(wxT("erreur affectation pourcentage fonte signature"));
    encadreur.SetPositionSignature(panel_signature->GetPosition());
    encadreur.SetCouleurSignature(panel_signature->GetCouleur());
    encadreur.SetSignature(panel_signature->GetSignature());

    encadreur.SetRepertoireSource(panel_choix_images->GetRepertoireSource());
    for (int num_sortie=0;num_sortie<nombre_encadrement;num_sortie++)
    {
        // si l'un des répertoires de destination n'existe pas, on le crée
        if (!wxDirExists(panel_parametres_sortie->GetRepertoireDestination(num_sortie))) 
            if (!wxMkdir(panel_parametres_sortie->GetRepertoireDestination(num_sortie)))
                wxLogFatalError(wxT("erreur à la création d'un des répertoires de sortie"));
        // on finit de fixer les paramètres d'encadrement
        encadreur.SetRepertoireDestination(panel_parametres_sortie->GetRepertoireDestination(num_sortie));
        encadreur.SetPrefixeFichier(panel_parametres_sortie->GetPrefixeFichier(num_sortie));
        encadreur.SetQualiteEnregistrement(panel_parametres_sortie->GetQualiteEnregistrement(num_sortie));
        encadreur.SetRedimensionnement(panel_parametres_sortie->GetTailleRedimensionement(num_sortie));
    
        bool cont=true;
        for (unsigned int i=0;i<liste_images.size();i++)
        {    
            wxString nomfichier(liste_images[i]);
            wxString locallog(panel_parametres_sortie->GetNomSortie(num_sortie));locallog<<wxT(": encadrement de ")<<nomfichier<<wxT(" ... ");
            log << locallog;
            cont=dialog.Update(num_sortie*nombre_images+i+1,locallog);
            if (!cont)
            {
                if (wxMessageBox(wxT("Voulez-vous réellement abandonner l'encadrement ?"),wxT("Encadre_image"),
                                                        wxYES_NO|wxICON_QUESTION)==wxYES) break;
                dialog.Resume();
            }            
            log<<encadreur.Encadre(nomfichier) <<wxT("\n");
        }
        if (!cont)
        {
            log <<wxT("\n")<<wxT("Encadrement annulé par l'utilisateur\n");
        }        
    }       
    return log;
}
